import { useRef } from 'react';
import Draggable from 'react-draggable';
import { clsxMerge } from '../clsx';
import { Resizable } from 're-resizable';

type DragModalProps = {
  title?: React.ReactNode;
  content?: React.ReactNode;
  onClose?: () => void;
  containerClassName?: string;
  handleClassName?: string;
  contentClassName?: string;
  /**
   * 默认大小, 单位为px
   * width: defaultSize.width || 320
   * height: defaultSize.height || 400
   */
  defaultSize?: {
    width: number;
    height: number;
  };
  style?: React.CSSProperties;
};
export const DragModal = (props: DragModalProps) => {
  const dragRef = useRef<HTMLDivElement>(null);

  return (
    <Draggable
      nodeRef={dragRef as any}
      onStop={(e, data) => {
        console.log(e, data);
      }}
      handle='.handle'
      grid={[1, 1]}
      scale={1}
      bounds='parent'
      defaultPosition={{
        x: 0,
        y: 0,
      }}>
      <div
        className={clsxMerge('absolute top-0 left-0 bg-white rounded-md border border-gray-200 shadow-sm', props.containerClassName)}
        ref={dragRef}
        style={props.style}>
        <div className={clsxMerge('handle cursor-move border-b border-gray-200 py-2 px-4', props.handleClassName)}>{props.title || 'Move'}</div>
        <Resizable
          className={clsxMerge('', props.contentClassName)}
          defaultSize={{
            width: props.defaultSize?.width || 600,
            height: props.defaultSize?.height || 400,
          }}
          onResizeStop={(e, direction, ref, d) => {
            // console.log(e, direction, ref, d);
          }}
          enable={{
            bottom: true,
            right: true,
            bottomRight: true,
          }}>
          {props.content}
        </Resizable>
      </div>
    </Draggable>
  );
};
